@@ -19,6 +19,7 @@ import math
 import datetime
 import pytz
 import base64
+import socket
 import re
 import simplejson as json
 from decimal import Context, ROUND_HALF_UP
@@ -55,6 +56,17 @@ def window(seq, window_size):
         st += window_size
 
 
+def get_host_ip():
+    try:
+        s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+        s.connect(('8.8.8.8', 80))
+        ip = s.getsockname()[0]
+    finally:
+        s.close()
+
+    return ip
+
+
 def get_platform():
     if "win" in sys.platform.lower():
         return "windows"
@@ -165,7 +177,7 @@ def read_parm(request):
     res.update(request.args)
     res.update(request.form)
 
-    if request.is_json:
+    if request.is_json and request.data:
         res.update(request.json)
     elif request.data != b'':
         res.update(json.loads(request.data.decode()))
